<?php 
/**
 * @file
 * This file handles all the conditional actions stuff
 *
 */
 
 
/**
 * Implementation of hook_ca_predicate().
 *
 * Mark a event registration webform as paid after checkout
 */

function uc_event_registration_ca_predicate() {  
 //When a checkout happens, check the balance and fire the action
  $configurations['uc_event_registration_mark_paid'] = array(
    '#title' => t('Mark Event Registrations as Paid'),
    '#description' => t('When a user checks out with an event registration we mark it paid after the order is complete.'),
    '#class' => 'Event Registration',
    '#trigger' => 'uc_order_status_update',
    '#status' => 1,
    '#conditions' => array(
      '#operator' => 'AND',
      '#conditions' => array(
        array(
          '#name' => 'uc_payment_condition_order_balance',
          '#title' => t('If the balance is less than or equal to $0.00.'),
          '#argument_map' => array(
            'order' => 'order',
          ),
          '#settings' => array(
            'negate' => FALSE,
            'balance_comparison' => 'less_equal',
          ),
        ),
        array(
          '#name' => 'uc_order_status_condition',
          '#title' => t('If the order status is Payment Received.'),
          '#argument_map' => array(
            'order' => 'order',
          ),
          '#settings' => array(
            'order_status' => 'payment_received',
          ),
        ),
      ),
    ),
    '#actions' => array(
      array(
        '#name' => 'uc_event_registration_mark_paid',
        '#title' => t('Mark Webform as Paid after Checkout'),
        '#argument_map' => array(
          'order' => 'order', 
        ),
      ),
    ),
  );
  $configurations['uc_event_registration_send_webform_emails'] = array(
    '#title' => t("Send Paid Event 'late' emails"),
    '#description' => t("For Paid Events send any emails configured for 'late' sending."),
    '#class' => 'Event Registration',
    '#trigger' => 'uc_checkout_complete',
    '#status' => 1,
    '#conditions' => array(
      '#operator' => 'AND',
      '#conditions' => array(
        array(
          '#name' => 'uc_cart_condition_product_class',
          '#title' => t("Order contains a Paid Event"),
          '#argument_map' => array(
            'order' => 'order',
          ),
          '#settings' => array(
            'negate' => FALSE,
            'class' => 'paidevent', 
          ),
        ),
      ),
    ),
    '#actions' => array(
      array(
        '#name' => 'uc_event_registration_send_webform_emails',
        '#title' => t("Send webform emails"),
        '#argument_map' => array(
          'order' => 'order', 
        ),
      ),
    ),
  );
  return $configurations;
}

/**
 * Implementation of hook_ca_action().
 *
 * Provides two actions:
 *   Mark an event registration webform as paid after checkout
 *   Send any emails configured to send on checkout completion
 */
function uc_event_registration_ca_action() {
  $order_arg = array(
    '#entity' => 'uc_order',
    '#title' => t('Order'),
  );

  $actions['uc_event_registration_mark_paid'] = array(
    '#title' => t('Mark Webform as Paid after Checkout'),
    '#category' => t('Event Registration'),
    '#callback' => 'uc_event_registration_mark_paid',
    '#arguments' => array(
      'order' => $order_arg,
    ),
  );
  
  $actions['uc_event_registration_send_webform_emails'] = array(
    '#title' => t('Send webform emails'),
    '#category' => t('Event Registration'),
    '#callback' => 'uc_event_registration_send_webform_emails',
    '#arguments' => array(
      'order' => $order_arg,
    ),
  );
  
  return $actions;
}
  
// Mark a webform as paid
function uc_event_registration_mark_paid(&$order, $settings) {
  foreach ($order->products as $theproduct) {
    $sid = $theproduct->data['uc_event_registration']['sid'];
    $value = db_query("UPDATE {webform_submitted_data} SET data = '%s' WHERE cid = %d AND sid = %d", 'paid', 2, $sid);
  }
  return $value;
}

/** 
 * Send all late emails associated with paidevents in this order.
 */
function uc_event_registration_send_webform_emails(&$order, $settings){
  // Include the webform submissions file which contains all email functions
  include_once drupal_get_path('module', 'webform') .'/includes/webform.submissions.inc';
  foreach ($order->products as $theproduct) {
    // load the node object which is used by the webform submission functions
    $node = node_load(array("nid" => $theproduct->nid));
    $sid = $theproduct->data['uc_event_registration']['sid'];
    $submission = webform_get_submission($theproduct->nid, $sid, TRUE);
    
    // Process node to remove emails that have already been sent
    _uc_event_registration_process_emails($node, UC_EVENT_REGISTRATION_EMAIL_ON_CHECKOUT);
    
    // now send the email
    webform_submission_send_mail($node, $submission);
  }
}